@@ -1,12 +1,11 @@
 #
-# $Id: String.pm,v 0.06 2004/01/03 22:16:32 sts Exp $
+# $Id: String.pm,v 0.07 2004/01/04 16:05:54 sts Exp $
 
 package Convert::ASCII::String;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
-use strict;
-no strict 'refs';
+use strict 'vars';
 use warnings;
 
 use Carp;
@@ -19,6 +18,10 @@ our (@EXPORT_OK, %EXPORT_TAGS, @subs);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ( 'all' => [ @subs ] );
 
+sub SUCCESS { 1 }
+sub ARGS_MISMATCH { -1 }
+sub SEP_MISMATCH { -2 }
+
 =head1 NAME
 
 Convert::ASCII::String - Convert character strings to ASCII and vice versa.
@@ -104,12 +107,12 @@ No scalar reference provided.
 sub string2ascii {
     my ($data_ref, $sep) = @_;
     $sep ||= ${__PACKAGE__.'::sep'} || '';
-    return -1 unless ref $data_ref eq 'SCALAR';
+    return ARGS_MISMATCH unless ref $data_ref eq 'SCALAR';
 
     my @ascii = unpack 'C*', $$data_ref;
     $$data_ref = join $sep, @ascii;
 
-    return 1;
+    return SUCCESS;
 }
 
 =head2 ascii2string
@@ -141,14 +144,14 @@ Separator mismatch.
 sub ascii2string {
     my ($data_ref, $sep) = @_;
     $sep ||= ${__PACKAGE__.'::sep'};
-    return -1 unless ref $data_ref eq 'SCALAR' && $sep;
+    return ARGS_MISMATCH unless ref $data_ref eq 'SCALAR' && $sep;
     $sep = quotemeta $sep;
-    return -2 if $$data_ref !~ /$sep/i;
+    return SEP_MISMATCH if $$data_ref !~ /$sep/i;
 
     my @ascii = split $sep, $$data_ref;
     $$data_ref = pack 'C*', @ascii;
 
-    return 1;
+    return SUCCESS;
 }
 
 1;
